==> kenga-labels-0.0.30.tgz: package/image-paragraph.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _assertThisInitialized = require('@babel/runtime/helpers/assertThisInitialized');
var _inherits = require('@babel/runtime/helpers/inherits');
var _possibleConstructorReturn = require('@babel/runtime/helpers/possibleConstructorReturn');
var _getPrototypeOf = require('@babel/runtime/helpers/getPrototypeOf');
var Ui = require('kenga/utils');
var Widget = require('kenga/widget');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _assertThisInitialized__default = /*#__PURE__*/_interopDefaultLegacy(_assertThisInitialized);
var _inherits__default = /*#__PURE__*/_interopDefaultLegacy(_inherits);
var _possibleConstructorReturn__default = /*#__PURE__*/_interopDefaultLegacy(_possibleConstructorReturn);
var _getPrototypeOf__default = /*#__PURE__*/_interopDefaultLegacy(_getPrototypeOf);
var Ui__default = /*#__PURE__*/_interopDefaultLegacy(Ui);
var Widget__default = /*#__PURE__*/_interopDefaultLegacy(Widget);

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf__default['default'](Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf__default['default'](this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn__default['default'](this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

var ImageParagraph = /*#__PURE__*/function (_Widget) {
  _inherits__default['default'](ImageParagraph, _Widget);

  var _super = _createSuper(ImageParagraph);

  function ImageParagraph(aElement, text, image, iconTextGap) {
    var _this;

    _classCallCheck__default['default'](this, ImageParagraph);

    if (arguments.length < 4) iconTextGap = 4;
    if (arguments.length < 3) image = null;
    if (arguments.length < 2) text = '';
    _this = _super.call(this, aElement);

    var self = _assertThisInitialized__default['default'](_this);

    var horizontalTextPosition = Ui__default['default'].HorizontalPosition.RIGHT;
    var verticalTextPosition = Ui__default['default'].VerticalPosition.CENTER;
    var paragraph = document.createElement('p');
    paragraph.classList.add('p-paragraph');

    _this.element.appendChild(paragraph);

    _this.element.classList.add('p-image-paragraph');

    function applyPosition() {
      self.element.classList.remove('p-image-paragraph-column');
      self.element.classList.remove('p-image-paragraph-row');
      self.element.classList.remove('p-image-paragraph-row-top');
      self.element.classList.remove('p-image-paragraph-row-bottom');

      if (image) {
        image.style.marginLeft = '';
        image.style.marginRight = '';
        image.style.marginTop = '';
        image.style.marginBottom = '';
      }

      if (horizontalTextPosition === Ui__default['default'].HorizontalPosition.CENTER) {
        self.element.classList.add('p-image-paragraph-column');

        if (verticalTextPosition === Ui__default['default'].VerticalPosition.TOP) {
          if (image) {
            self.element.insertBefore(paragraph, image);
            if (iconTextGap > 0 && text) image.style.marginTop = "".concat(iconTextGap, "px");
          }
        } else if (verticalTextPosition === Ui__default['default'].VerticalPosition.BOTTOM || verticalTextPosition === Ui__default['default'].VerticalPosition.CENTER) {
          if (image) {
            self.element.insertBefore(image, paragraph);
            if (iconTextGap > 0 && text) image.style.marginBottom = "".concat(iconTextGap, "px");
          }
        } // else // value of 'verticalTextPosition' is unknown

      } else {
        self.element.classList.add('p-image-paragraph-row');

        if (horizontalTextPosition === Ui__default['default'].HorizontalPosition.LEFT) {
          if (image) {
            self.element.insertBefore(paragraph, image);
            if (iconTextGap > 0 && text) image.style.marginLeft = "".concat(iconTextGap, "px");
          }
        } else if (horizontalTextPosition === Ui__default['default'].HorizontalPosition.RIGHT) {
          if (image) {
            self.element.insertBefore(image, paragraph);
            if (iconTextGap > 0 && text) image.style.marginRight = "".concat(iconTextGap, "px");
          }
        } // else // value of 'horizontalTextPosition' is unknown


        if (verticalTextPosition === Ui__default['default'].VerticalPosition.TOP) {
          self.element.classList.add('p-image-paragraph-row-top');
        } else if (verticalTextPosition === Ui__default['default'].VerticalPosition.BOTTOM) {
          self.element.classList.add('p-image-paragraph-row-bottom');
        } // else // value of 'verticalTextPosition' is unknown

      }
    }

    function applyText() {
      paragraph.innerText = text != null ? text : ''; // Some browsers treat null here as value to be converted to string as 'null'. Mobile Edge, for example.
    }

    applyPosition();
    applyText();

    function iconByString(aValue) {
      var img = document.createElement('img');
      img.src = aValue;
      return img;
    }

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'icon', {
      get: function get() {
        return image;
      },
      set: function set(aValue) {
        if (image !== aValue) {
          if (image) {
            image.classList.remove('p-image');
            self.element.removeChild(image);
          }

          image = typeof aValue === 'string' ? iconByString(aValue) : aValue;

          if (image) {
            self.element.appendChild(image);
            image.classList.add('p-image');
            applyPosition();
          }
        }
      }
    });
    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'text', {
      get: function get() {
        return text;
      },
      set: function set(aValue) {
        if (text !== aValue) {
          text = aValue;
          applyText();
        }
      }
    });
    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'iconTextGap', {
      get: function get() {
        return iconTextGap;
      },
      set: function set(aValue) {
        iconTextGap = aValue;
      }
    });
    /**
     * Horizontal position of the text relative to the icon.
     */

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'horizontalTextPosition', {
      get: function get() {
        return horizontalTextPosition;
      },
      set: function set(aValue) {
        if (horizontalTextPosition !== aValue) {
          horizontalTextPosition = aValue;
          applyPosition();
        }
      }
    });
    /**
     * Vertical position of the text relative to the icon.
     */

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'verticalTextPosition', {
      get: function get() {
        return verticalTextPosition;
      },
      set: function set(aValue) {
        if (verticalTextPosition !== aValue) {
          verticalTextPosition = aValue;
          applyPosition();
        }
      }
    });
    return _this;
  }

  return ImageParagraph;
}(Widget__default['default']);

module.exports = ImageParagraph;

==> kenga-labels-0.0.38.tgz: package/image-paragraph.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _assertThisInitialized = require('@babel/runtime/helpers/assertThisInitialized');
var _inherits = require('@babel/runtime/helpers/inherits');
var _possibleConstructorReturn = require('@babel/runtime/helpers/possibleConstructorReturn');
var _getPrototypeOf = require('@babel/runtime/helpers/getPrototypeOf');
var Ui = require('kenga/utils');
var Widget = require('kenga/widget');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _assertThisInitialized__default = /*#__PURE__*/_interopDefaultLegacy(_assertThisInitialized);
var _inherits__default = /*#__PURE__*/_interopDefaultLegacy(_inherits);
var _possibleConstructorReturn__default = /*#__PURE__*/_interopDefaultLegacy(_possibleConstructorReturn);
var _getPrototypeOf__default = /*#__PURE__*/_interopDefaultLegacy(_getPrototypeOf);
var Ui__default = /*#__PURE__*/_interopDefaultLegacy(Ui);
var Widget__default = /*#__PURE__*/_interopDefaultLegacy(Widget);

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf__default['default'](Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf__default['default'](this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn__default['default'](this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function iconByString(aValue) {
  var img = document.createElement('img');
  img.src = aValue;
  return img;
}

var ImageParagraph = /*#__PURE__*/function (_Widget) {
  _inherits__default['default'](ImageParagraph, _Widget);

  var _super = _createSuper(ImageParagraph);

  function ImageParagraph(aElement, text, image, iconTextGap) {
    var _this;

    _classCallCheck__default['default'](this, ImageParagraph);

    if (arguments.length < 4) iconTextGap = '4px';
    if (arguments.length < 3) image = null;
    if (arguments.length < 2) text = '';
    _this = _super.call(this, aElement);

    var self = _assertThisInitialized__default['default'](_this);

    image = typeof image === 'string' ? iconByString(image) : image;
    var horizontalTextPosition = Ui__default['default'].HorizontalPosition.RIGHT;
    var verticalTextPosition = Ui__default['default'].VerticalPosition.CENTER;
    var paragraph = document.createElement('p');
    paragraph.classList.add('p-paragraph');

    _this.element.appendChild(paragraph);

    _this.element.classList.add('p-image-paragraph');

    function applyPosition() {
      self.element.classList.remove('p-image-paragraph-column');
      self.element.classList.remove('p-image-paragraph-row');
      self.element.classList.remove('p-image-paragraph-row-top');
      self.element.classList.remove('p-image-paragraph-row-bottom');

      if (image) {
        image.style.marginLeft = '';
        image.style.marginRight = '';
        image.style.marginTop = '';
        image.style.marginBottom = '';
      }

      if (horizontalTextPosition === Ui__default['default'].HorizontalPosition.CENTER) {
        self.element.classList.add('p-image-paragraph-column');

        if (verticalTextPosition === Ui__default['default'].VerticalPosition.TOP) {
          if (image) {
            self.element.insertBefore(paragraph, image);
            if (iconTextGap && text) image.style.marginTop = iconTextGap;
          }
        } else if (verticalTextPosition === Ui__default['default'].VerticalPosition.BOTTOM || verticalTextPosition === Ui__default['default'].VerticalPosition.CENTER) {
          if (image) {
            self.element.insertBefore(image, paragraph);
            if (iconTextGap && text) image.style.marginBottom = iconTextGap;
          }
        } // else // value of 'verticalTextPosition' is unknown

      } else {
        self.element.classList.add('p-image-paragraph-row');

        if (horizontalTextPosition === Ui__default['default'].HorizontalPosition.LEFT) {
          if (image) {
            self.element.insertBefore(paragraph, image);
            if (iconTextGap && text) image.style.marginLeft = iconTextGap;
          }
        } else if (horizontalTextPosition === Ui__default['default'].HorizontalPosition.RIGHT) {
          if (image) {
            self.element.insertBefore(image, paragraph);
            if (iconTextGap && text) image.style.marginRight = iconTextGap;
          }
        } // else // value of 'horizontalTextPosition' is unknown


        if (verticalTextPosition === Ui__default['default'].VerticalPosition.TOP) {
          self.element.classList.add('p-image-paragraph-row-top');
        } else if (verticalTextPosition === Ui__default['default'].VerticalPosition.BOTTOM) {
          self.element.classList.add('p-image-paragraph-row-bottom');
        } // else // value of 'verticalTextPosition' is unknown

      }
    }

    function applyText() {
      paragraph.innerText = text != null ? text : ''; // Some browsers treat null here as value to be converted to string as 'null'. Mobile Edge, for example.
    }

    applyPosition();
    applyText();
    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'icon', {
      get: function get() {
        return image;
      },
      set: function set(aValue) {
        if (image !== aValue) {
          if (image) {
            self.element.removeChild(image);
            image.classList.remove('p-image');
          }

          image = typeof aValue === 'string' ? iconByString(aValue) : aValue;

          if (image) {
            image.classList.add('p-image');
            self.element.appendChild(image);
            applyPosition();
          }
        }
      }
    });
    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'text', {
      get: function get() {
        return text;
      },
      set: function set(aValue) {
        if (text !== aValue) {
          text = aValue;
          applyText();
        }
      }
    });
    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'iconTextGap', {
      get: function get() {
        return iconTextGap;
      },
      set: function set(aValue) {
        iconTextGap = typeof aValue === 'number' ? "".concat(aValue, "px") : aValue;
        applyPosition();
      }
    });
    /**
     * Horizontal position of the text relative to the icon.
     */

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'horizontalTextPosition', {
      get: function get() {
        return horizontalTextPosition;
      },
      set: function set(aValue) {
        if (horizontalTextPosition !== aValue) {
          horizontalTextPosition = aValue;
          applyPosition();
        }
      }
    });
    /**
     * Vertical position of the text relative to the icon.
     */

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'verticalTextPosition', {
      get: function get() {
        return verticalTextPosition;
      },
      set: function set(aValue) {
        if (verticalTextPosition !== aValue) {
          verticalTextPosition = aValue;
          applyPosition();
        }
      }
    });
    return _this;
  }

  return ImageParagraph;
}(Widget__default['default']);

module.exports = ImageParagraph;
